aboutsummaryrefslogtreecommitdiff
path: root/obj_tree.go
diff options
context:
space:
mode:
authorGravatar Runxi Yu2025-11-16 00:00:00 +0000
committerGravatar Runxi Yu2025-11-16 00:00:00 +0000
commitdaeaee2c564caadc62db9e011e4e9c8213aeb005 (patch)
treee58b8265e4d6b875674bf05dfd83ecd4d2cab71b /obj_tree.go
parentIgnore error on f.Close() (diff)
signature
Rename ObjType -> ObjectType
Diffstat (limited to 'obj_tree.go')
-rw-r--r--obj_tree.go4
1 files changed, 2 insertions, 2 deletions
diff --git a/obj_tree.go b/obj_tree.go
index 0a7e6a97..66fdb8bd 100644
--- a/obj_tree.go
+++ b/obj_tree.go
@@ -20,8 +20,8 @@ type TreeEntry struct {
ID Hash
}
-// ObjType allows Tree to satisfy the Object interface.
-func (*Tree) ObjType() ObjType {
+// ObjectType allows Tree to satisfy the Object interface.
+func (*Tree) ObjectType() ObjectType {
return ObjTree
}